@@ -6,13 +6,20 @@
 #define HAVE_PQEXECPARAMS 1
 #define HAVE_PQESCAPESTRING 1
 #define HAVE_PQESCAPESTRINGCONN 1
+#define HAVE_PQESCAPELITERAL 1
+#define HAVE_PQESCAPEIDENTIFIER 1
 #define HAVE_PQGETCANCEL 1
 #define HAVE_LO_CREATE 1
 #define HAVE_PG_ENCODING_TO_CHAR 1
+#define HAVE_PG_CHAR_TO_ENCODING 1
 #define HAVE_PQSETCLIENTENCODING 1
+#define HAVE_PQLIBVERSION 1
+#define HAVE_PQPING 1
 #define HAVE_RB_ENCDB_ALIAS 1
+#define HAVE_CONST_PGRES_COPY_BOTH 1
 #define HAVE_STRUCT_PGNOTIFY_EXTRA 1
 #define HAVE_ST_EXTRA 1
 #define HAVE_ST_NOTIFY_EXTRA 1
 #define HAVE_UNISTD_H 1
+#define HAVE_RUBY_ST_H 1
 #endif
